@@ -15,7 +15,7 @@
   */
 
 #ifndef lint
-static char sccsid[] = "@(#) tcpdchk.c 1.5 95/01/11 10:41:24";
+static char sccsid[] = "@(#) tcpdchk.c 1.7 96/02/11 17:01:34";
 #endif
 
 /* System libraries. */
@@ -40,6 +40,10 @@ extern char *optarg;
 #define INADDR_NONE     (-1)		/* XXX should be 0xffffffff */
 #endif
 
+#ifndef S_ISDIR
+#define S_ISDIR(m)	(((m) & S_IFMT) == S_IFDIR)
+#endif
+
 /* Application-specific. */
 
 #include "tcpd.h"
@@ -53,6 +57,7 @@ static char sep[] = ", \t\n";
 
 #define	BUFLEN 2048
 
+int     resident = 0;
 int     hosts_access_verbose = 0;
 char   *hosts_allow_table = HOSTS_ALLOW;
 char   *hosts_deny_table = HOSTS_DENY;
@@ -118,6 +123,15 @@ char  **argv;
     if (argc != optind)
 	usage();
 
+    /*
+     * When confusion really strikes...
+     */
+    if (check_path(REAL_DAEMON_DIR, &st) < 0) {
+	tcpd_warn("REAL_DAEMON_DIR %s: %m", REAL_DAEMON_DIR);
+    } else if (!S_ISDIR(st.st_mode)) {
+	tcpd_warn("REAL_DAEMON_DIR %s is not a directory", REAL_DAEMON_DIR);
+    }
+
     /*
      * Process the inet configuration file (or its moral equivalent). This
      * information is used later to find references in hosts.allow/deny to
@@ -371,7 +385,8 @@ char   *pat;
 	tcpd_warn("%s: user name begins with dot", pat);
     } else if (pat[strlen(pat) - 1] == '.') {
 	tcpd_warn("%s: user name ends in dot", pat);
-    } else if (STR_EQ(pat, "ALL") || STR_EQ(pat, unknown)) {
+    } else if (STR_EQ(pat, "ALL") || STR_EQ(pat, unknown)
+	       || STR_EQ(pat, "KNOWN")) {
 	 /* void */ ;
     } else if (STR_EQ(pat, "FAIL")) {		/* obsolete */
 	tcpd_warn("FAIL is no longer recognized");
